@@ -7,7 +7,7 @@ use strict;
 use Carp;
 use Getopt::Long qw(GetOptionsFromString);
 
-use version; our $VERSION = qv('v0.3.0');
+use version; our $VERSION = qv('v0.3.1');
 
 # Module implementation here
 
@@ -17,9 +17,12 @@ my @optdefs = qw(
     comment=s
     ctstate=s
     destination|d=s
-    dport=s
     destination-ports|dports=s
+    dport=s
+    dst-type=s
     gid-owner=s
+    goto|g=s
+    helper=s
     in-interface|i=s
     icmp-type=s
     jump|j=s
@@ -29,6 +32,7 @@ my @optdefs = qw(
     m=s
     mac-source=s
     match-set=s
+    mss=s
     notrack
     o=s
     physdev-in=s
@@ -175,11 +179,13 @@ sub _dot_nodes {
     my ($self,$opt,$table) = @_;
     my @nodes = ();
     my %used = ();
-    unless ($opt->{showunusednodes}) {
+    unless ($opt->{showunusednodes} || $opt->{"use-numbered-nodes"}) {
         %used = map { $_->[0] => 1, } @{$self->{jumps}->{$table}};
     }
     foreach my $node (keys %{$self->{chains}->{$table}}) {
-        next unless ($used{$node} || $opt->{showunusednodes});
+        next unless ($used{$node}
+                    || $opt->{showunusednodes}
+                    || $opt->{"use-numbered-nodes"});
         my @rules = ();
         my $rn = 0;
         if ($opt->{showrules}) {
@@ -234,13 +240,20 @@ sub _internal_nodes {
     my %have_node = ();
     my %used      = ();
     foreach my $table (@_) {
-        unless ($opt->{showunusednodes}) {
+        unless ($opt->{showunusednodes} || $opt->{"use-numbered-nodes"}) {
             %used = map { $_->[0] => 1, } @{$self->{jumps}->{$table}};
         }
         foreach my $node (sort keys %{$self->{chains}->{$table}}) {
-            next unless ($used{$node} || $opt->{showunusednodes});
+            next unless ($used{$node}
+                        || $opt->{showunusednodes}
+                        || $opt->{"use-numbered-nodes"});
             if (!$have_node{$node} && $node =~ $re_in) {
-                push @nodes, qq("$node");
+                if ($opt->{"use-numbered-nodes"}) {
+                    push @nodes, $self->{nodemap}->{$node} || qq("$node");
+                }
+                else {
+                    push @nodes, qq("$node");
+                }
                 $have_node{$node} = 1;
             }
         }
@@ -281,8 +294,12 @@ sub _read_iptables_line {
         my ($ret, $args) = GetOptionsFromString($rule,\%opt,@optdefs);
         if ($ret) {
             my $iface = $opt{'in-interface'} || '';
-            my $target = $opt{'jump'} || '';
+            my $target = $opt{'jump'} || $opt{'goto'} || '';
             unless ($target =~ /^(ACCEPT|DROP|REJECT)$/) {
+                unless ($self->{nodemap}->{$1}) {
+                        $self->{nodemap}->{$1} = "node" . $self->{nn};
+                        $self->{nn} += 1;
+                }
                 my $rn = scalar @{$self->{chains}{$last_table}->{$chain}->{rules}};
                 push @{$self->{jumps}->{$last_table}}, [ $chain, $target, $iface, $rn ];
             }
@@ -308,7 +325,7 @@ App::Iptables2Dot - turn iptables-save output into graphs for GraphViz
 
 =head1 VERSION
 
-This document describes App::Iptables2Dot version v0.3.0
+This document describes App::Iptables2Dot version v0.3.1
 
 
 =head1 SYNOPSIS
